@@ -73,7 +73,7 @@ class ModelConverter:
             params["validate"].append(ma_validate.OneOf(choices, labels))
 
         if field.help_text:
-            params["metadata"] = {"help_text": field.help_text}
+            params["metadata"] = {"description": field.help_text}
 
         # use first "known" field class from field class mro
         # so that extended field classes get converted correctly
